/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration FT90x :
    
    MCU             : FT900
    Dev. Board      : EasyFT90x v7 
    SW              : mikroC PRO for FT900x v2.2.1

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/

sbit MUX_A0_PIN at GPIO_PIN1_bit;

sbit BUCK_ENABLE_PIN at GPIO_PIN28_bit;

sbit MUX_A1_PIN at GPIO_PIN56_bit;

sbit PG_PIN at GPIO_PIN3_bit;

void systemInit()
{
    UART1_Init(9600);
    delay_ms(1000);
}

void Buck_Init()
{
    GPIO_Digital_Output( &GPIO_PORT_00_07, _GPIO_PINMASK_1 );
    GPIO_Digital_Output( &GPIO_PORT_24_31, _GPIO_PINMASK_4 );
    GPIO_Digital_Output( &GPIO_PORT_56_63, _GPIO_PINMASK_0 );
    GPIO_Digital_Input ( &GPIO_PORT_00_07, _GPIO_PINMASK_3 );
    BUCK_ENABLE_PIN = 1;
    asm nop;
    MUX_A0_PIN = 0;
    asm  nop;
    MUX_A1_PIN = 0;

}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART1_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART1_Write_Text( "\r\n" );
        delay_ms(1000);
    }
}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
            Buck_Task();
    }
}